Learn R Programming

vvdoctor (version 0.0.2)

determine_independent_variable: Determine the Type of Independent Variable

Description

This function determines the type of the independent variable based on its data type and the number of unique values.

Usage

determine_independent_variable(independent_var)

Value

A character string indicating the type of the independent variable.

Arguments

independent_var

A vector representing the independent variable.