perform_statistical_test: Perform Statistical Test
Description
This function performs the appropriate statistical test based on the user's input.
Usage
perform_statistical_test(data, input)
Value
The result of the statistical test.
Arguments
- data
A data frame containing the variables.
- input
A list containing the user's input, including the selected statistical test, dependent variable, independent variable, identifier variable, and input mean.