Learn R Programming

vvdoctor (version 0.0.2)

run_vvdoctor: Run the Statistical Test App

Description

This function starts the Shiny app, which allows users to upload data and perform statistical tests on the dataset.

Usage

run_vvdoctor()

Arguments

Value

No return value, the function runs the Shiny app

Examples

Run this code
if (interactive()) {
  run_vvdoctor()
}

Run the code above in your browser using DataLab