This function launches a Shiny application that allows users to upload data
and perform various statistical tests on the dataset. Users can select the
dependent and independent variables, choose the appropriate statistical test,
and view the results.
Usage
diagnose()
Arguments
Value
NULL The function does not return a value, but launches the Shiny app.